@@ -4,7 +4,7 @@ mod core;
 mod bindings;
 
 #[pymodule]
-fn suma_ulsa(_py: Python, m: &Bound<'_, PyModule>) -> PyResult<()> {
+fn suma_ulsa_native(_py: Python, m: &Bound<'_, PyModule>) -> PyResult<()> {
     bindings::register_modules(m)?;
     Ok(())
 }
