@@ -38,8 +38,7 @@ __all__ = [
     "truth_table_from_expr",
 
     # Networking
-    "SubnetCalculator",
+    "FLSMCalculator",
     "SubnetRow",
-    "create_subnet_calculator",
-    "calculate_subnets"
+    "VLSMCalculator"
 ]
