@@ -9,8 +9,7 @@ except ImportError:
     pass
 
 __all__ = [
-    "SubnetCalculator",
-    "create_subnet_calculator",
-    "calculate_subnets",
-    "SubnetRow"
+    "FLSMCalculator",
+    "SubnetRow",
+    "VLSMCalculator"
 ]
\ No newline at end of file
